@@ -6,7 +6,7 @@
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="56"/>
         <source>Customize Conky - %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Prilagodi Conky -%1</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="77"/>
@@ -38,27 +38,27 @@
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="121"/>
         <source>Color0</source>
-        <translation type="unfinished"></translation>
+        <translation>Barva0</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="121"/>
         <source>Color1</source>
-        <translation type="unfinished"></translation>
+        <translation>Barva1</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="121"/>
         <source>Color2</source>
-        <translation type="unfinished"></translation>
+        <translation>Barva2</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="121"/>
         <source>Color3</source>
-        <translation type="unfinished"></translation>
+        <translation>Barva3</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="121"/>
         <source>Color4</source>
-        <translation type="unfinished"></translation>
+        <translation>Barva4</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="122"/>
@@ -99,74 +99,75 @@
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="684"/>
         <source>Select Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbira barve</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="790"/>
         <source>Permission Denied</source>
-        <translation type="unfinished"></translation>
+        <translation>Zavrnitev dovoljenja</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="791"/>
         <source>Cannot write to file: %1
 Insufficient permissions.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ne morem pisati v datoteko: %1
+Nimate dovolj pravic.</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="801"/>
         <source>Write Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Napaka pri zapisovanju</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="801"/>
         <source>Cannot write to file: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ne morem pisati v datoteko: %1</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="874"/>
         <source>Backup Config File</source>
-        <translation type="unfinished"></translation>
+        <translation>Varnostna kopija nastavitvene datoteke</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="874"/>
         <source>Do you want to preserve the original file?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ali bi radi ohranili izvirno datoteko?</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="897"/>
         <source>Backed Up Config File</source>
-        <translation type="unfinished"></translation>
+        <translation>Varnostna kopija nastavitvene datoteke</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="898"/>
         <source>The original configuration was backed up to %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Izvirna nastavitvena datoteka je bila shranjena kot %1</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="900"/>
         <source>Backup Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Varnostno kopiranje ni uspelo</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="900"/>
         <source>Failed to create a backup file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ni bilo mogoče ustvariti varnostne kopije</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="973"/>
         <location filename="../src/conkycustomizedialog.cpp" line="976"/>
         <source>Restore Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Obnovitev ni uspela</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="973"/>
         <source>Failed to restore from backup file.</source>
-        <translation type="unfinished"></translation>
+        <translation>Obnovitev iz varnostne kopije ni bila uspešna</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="976"/>
         <source>Backup file does not exist.</source>
-        <translation type="unfinished"></translation>
+        <translation>Varnostna kopija ne obstaja</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1328"/>
@@ -176,72 +177,72 @@ Insufficient permissions.</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
         <source>Alignment</source>
-        <translation type="unfinished"></translation>
+        <translation>Poravnava</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1340"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Zgoraj levo</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1341"/>
         <source>Top Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Zgoraj desno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
         <source>Top Middle</source>
-        <translation type="unfinished"></translation>
+        <translation>Zgoraj sredina</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1343"/>
         <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Spodaj levo</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1344"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Spodaj desno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1345"/>
         <source>Bottom Middle</source>
-        <translation type="unfinished"></translation>
+        <translation>Spodaj sredina</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1346"/>
         <source>Middle Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Sredina levo</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
         <source>Middle Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Sredina desno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
         <source>Middle Middle</source>
-        <translation type="unfinished"></translation>
+        <translation>Sredina sredina</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
         <source>Horizontal Gap</source>
-        <translation type="unfinished"></translation>
+        <translation>Vodoravni razmik</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
         <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
-        <translation type="unfinished"></translation>
+        <translation>[GAP_X] Vodoravni odmik od roba okna (v pikslih)</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1366"/>
         <source>Vertical Gap</source>
-        <translation type="unfinished"></translation>
+        <translation>Navpični razmik</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1367"/>
         <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
-        <translation type="unfinished"></translation>
+        <translation>[GAP_X] Navpični odmik od roba okna (v pikslih)</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1379"/>
@@ -267,28 +268,30 @@ Insufficient permissions.</source>
         <location filename="../src/conkycustomizedialog.cpp" line="1407"/>
         <source>Width should be larger than the size of window contents,
 otherwise this setting will not have any effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Širina naj bo večja od vsebine okna,
+sicer nastavitev nima učinka</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1411"/>
         <source>Minimum Width</source>
-        <translation type="unfinished"></translation>
+        <translation>Najmanjša širina</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1426"/>
         <source>Height should be larger than the size of window contents,
 otherwise this setting will not have any effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Višina naj bo večja od vsebine okna,
+sicer nastavitev nima učinka</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1428"/>
         <source>Minimum Height</source>
-        <translation type="unfinished"></translation>
+        <translation>Najmanjša višina</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1442"/>
         <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
-        <translation type="unfinished"></translation>
+        <translation>Višino okna lahko povečate z dodajanjem praznih vrstic na konec Conky nastavitvene datoteke</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1443"/>
@@ -303,39 +306,41 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1471"/>
         <source>Transparency Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Vsrata prosojnosti</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1476"/>
         <source>Opaque</source>
-        <translation type="unfinished"></translation>
+        <translation>Neprosojno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1477"/>
         <source>Transparent</source>
-        <translation type="unfinished"></translation>
+        <translation>Prosojno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
         <source>Pseudo-Transparent</source>
-        <translation type="unfinished"></translation>
+        <translation>Psevdo-prosojno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1479"/>
         <source>Semi-Transparent</source>
-        <translation type="unfinished"></translation>
+        <translation>Pol-prosojno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
         <source>Opacity (%)</source>
-        <translation type="unfinished"></translation>
+        <translation>Neprosojnost (%)</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
         <source>Window Opacity
 
 0 = Fully Transparent, 100 = Fully Opaque</source>
-        <translation type="unfinished"></translation>
+        <translation>Neprosojnost okna
+
+0=popolnoma prosojno, 100=neprosojno</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
@@ -345,17 +350,17 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1504"/>
         <source>Choose Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbira barve</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1524"/>
         <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastvitev vrste na &quot;Prosojno&quot; bo naredilo okno popolnoma prosojno (tudi slike). Uporabite &quot;Psevdo-prosojno&quot;, če želite, da slike ostanejo neprosojne.</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
         <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastavitev vrste na &quot;Psevdo-prosojno&quot; bo naredilo okno prosojno, okno pa bo imelo senco. Senco lahko odpravite v upravljalniku oken.</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1545"/>
@@ -412,12 +417,12 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1605"/>
         <source>12 Hour</source>
-        <translation type="unfinished"></translation>
+        <translation>12 ur</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1606"/>
         <source>24 Hour</source>
-        <translation type="unfinished"></translation>
+        <translation>24 ur</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1621"/>
@@ -432,22 +437,22 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1642"/>
         <source>WiFi</source>
-        <translation type="unfinished"></translation>
+        <translation>WiFi</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1645"/>
         <source>WiFi Network</source>
-        <translation type="unfinished"></translation>
+        <translation>WiFi omrežje</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1648"/>
         <source>LAN</source>
-        <translation type="unfinished"></translation>
+        <translation>LAN</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1651"/>
         <source>Wired LAN Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Ožičeno LAN omrežje</translation>
     </message>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1665"/>
@@ -457,7 +462,7 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkycustomizedialog.cpp" line="1928"/>
         <source>Select Background Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbira barve ozadja</translation>
     </message>
 </context>
 <context>
@@ -465,40 +470,40 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/conkylistwidget.cpp" line="63"/>
         <source>Running</source>
-        <translation type="unfinished"></translation>
+        <translation>Se izvaja</translation>
     </message>
     <message>
         <location filename="../src/conkylistwidget.cpp" line="63"/>
         <source>Stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaustavljeno</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="115"/>
+        <location filename="../src/conkylistwidget.cpp" line="118"/>
         <source>Autostart</source>
         <translation>Samodejni zagon</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="117"/>
+        <location filename="../src/conkylistwidget.cpp" line="120"/>
         <source>Edit</source>
         <translation>Uredi</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="120"/>
+        <location filename="../src/conkylistwidget.cpp" line="123"/>
         <source>Customize</source>
-        <translation type="unfinished"></translation>
+        <translation>Prilagajanje</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="125"/>
+        <location filename="../src/conkylistwidget.cpp" line="128"/>
         <source>Delete</source>
         <translation>Izbriši</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="154"/>
+        <location filename="../src/conkylistwidget.cpp" line="157"/>
         <source>Stop</source>
         <translation>Zaustavi</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="157"/>
+        <location filename="../src/conkylistwidget.cpp" line="160"/>
         <source>Start</source>
         <translation>Začni</translation>
     </message>
@@ -506,42 +511,42 @@ otherwise this setting will not have any effect</source>
 <context>
     <name>ConkyListWidget</name>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="313"/>
+        <location filename="../src/conkylistwidget.cpp" line="319"/>
         <source>Total: 0 conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>Skupaj conkijevj: 0</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="542"/>
+        <location filename="../src/conkylistwidget.cpp" line="551"/>
         <source>Total: %1 conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>Skupaj conkijevj: %1</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="545"/>
+        <location filename="../src/conkylistwidget.cpp" line="554"/>
         <source>Showing: %1 of %2 conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikazano conkijev: %1 od %2</translation>
     </message>
 </context>
 <context>
     <name>ConkyPreviewWidget</name>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="494"/>
+        <location filename="../src/conkylistwidget.cpp" line="503"/>
         <source>No Conky Selected</source>
-        <translation type="unfinished"></translation>
+        <translation>Noben conky ni izbran</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="496"/>
+        <location filename="../src/conkylistwidget.cpp" line="505"/>
         <source>Select a conky from the list to see its preview</source>
-        <translation type="unfinished"></translation>
+        <translation>S seznama izberite conky za predogled</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="515"/>
+        <location filename="../src/conkylistwidget.cpp" line="524"/>
         <source>Preview image could not be loaded</source>
-        <translation type="unfinished"></translation>
+        <translation>Slike za predogled ni bilo mogoče naložiti</translation>
     </message>
     <message>
-        <location filename="../src/conkylistwidget.cpp" line="518"/>
+        <location filename="../src/conkylistwidget.cpp" line="527"/>
         <source>No preview image available</source>
-        <translation type="unfinished"></translation>
+        <translation>Ni slike za predogled</translation>
     </message>
 </context>
 <context>
@@ -580,7 +585,7 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/mainwindow.cpp" line="149"/>
         <source>Loading Conky configurations...</source>
-        <translation type="unfinished"></translation>
+        <translation>Nalaganje Conky konfigracij...</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="172"/>
@@ -590,7 +595,7 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/mainwindow.cpp" line="174"/>
         <source>Configure conky search paths</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastavi poti za iskanje conkijev</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="176"/>
@@ -600,49 +605,49 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/mainwindow.cpp" line="178"/>
         <source>Refresh conky list</source>
-        <translation type="unfinished"></translation>
+        <translation>Osveži seznam conkijev</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="180"/>
         <source>Start All</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaženi vse</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="182"/>
         <source>Start all enabled conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaženi vse izbrane conkije</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="184"/>
         <source>Stop All</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaustavi vse</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="186"/>
         <source>Stop all running conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>zaustavi vse zagnane conkije</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="916"/>
         <location filename="../src/mainwindow.cpp" line="953"/>
         <source>Running</source>
-        <translation type="unfinished"></translation>
+        <translation>Se izvaja</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="918"/>
         <location filename="../src/mainwindow.cpp" line="954"/>
         <source>Stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaustavljeno</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="194"/>
         <source>Search conky by name...</source>
-        <translation type="unfinished"></translation>
+        <translation>Iskanje conkija po imenu...</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="196"/>
         <source>Search conkies by name (Ctrl+F)</source>
-        <translation type="unfinished"></translation>
+        <translation>Pošči Conky po imenu (Crtl+F)</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="241"/>
@@ -653,57 +658,59 @@ otherwise this setting will not have any effect</source>
         <location filename="../src/mainwindow.cpp" line="417"/>
         <location filename="../src/mainwindow.cpp" line="593"/>
         <source>Copy Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopiraj Conky</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="463"/>
         <location filename="../src/mainwindow.cpp" line="641"/>
         <source>Conky Copied</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky je skopiran</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="464"/>
         <source>Conky has been copied to your personal folder for editing:
 %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky je bil prekopiran v osebno mapo za urejanje:
+%1</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="466"/>
         <location filename="../src/mainwindow.cpp" line="644"/>
         <source>Copy Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopiranje ni uspelo</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="466"/>
         <location filename="../src/mainwindow.cpp" line="644"/>
         <source>Failed to copy conky to your personal folder.</source>
-        <translation type="unfinished"></translation>
+        <translation>Conkija ni bilo mogoče kopirati v osebno mapo.</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="528"/>
         <source>Delete Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbriši Conky</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="642"/>
         <source>Conky has been copied to your personal folder for customization:
 %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky je bil prekopiran v osebno mapo za prilagajnje:
+%1</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="561"/>
         <source>Delete Successful</source>
-        <translation type="unfinished"></translation>
+        <translation>Uspešno izbrisano</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="168"/>
         <source>Previews</source>
-        <translation type="unfinished"></translation>
+        <translation>Predogled</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="170"/>
         <source>Generate preview images for conkies</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustvari slike za predogled conkijev</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="190"/>
@@ -717,44 +724,47 @@ otherwise this setting will not have any effect</source>
     <message>
         <location filename="../src/mainwindow.cpp" line="191"/>
         <source>Filter conkies by running status or location</source>
-        <translation type="unfinished"></translation>
+        <translation>Filtriraj conkije glede na stanje zagona ali lokacijo</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="413"/>
         <location filename="../src/mainwindow.cpp" line="589"/>
         <source>Enter a name for the copy:</source>
-        <translation type="unfinished"></translation>
+        <translation>Vnesite ime za kopijo:</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="414"/>
         <location filename="../src/mainwindow.cpp" line="590"/>
         <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
 Enter a name for the copy.</source>
-        <translation type="unfinished"></translation>
+        <translation>Za urejanje in shranjevanje conkijev jih je potrebno najprej prekopirati v  ~/.conky, kjer morate imeti pravice.
+Vnesite ime kopiije.</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="431"/>
         <location filename="../src/mainwindow.cpp" line="609"/>
         <source>Directory Exists</source>
-        <translation type="unfinished"></translation>
+        <translation>Mapa obstaja</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="432"/>
         <location filename="../src/mainwindow.cpp" line="610"/>
         <source>A conky with the name &apos;%1&apos; already exists in your personal folder.
 Do you want to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky z imenom &quot;%1&quot; že obstaja v osebni mapi.
+Ga želite prepisati?</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="499"/>
         <source>Edit Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>Uredi Conky</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="500"/>
         <source>This conky file is read-only and requires administrator privileges to edit.
 Do you want to edit it with elevated privileges?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta conky je zgolj za branje in za urejanje potrebuje skrbniške pravice.
+Ali želite urejanje s povečanimi pravicami?</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="529"/>
@@ -762,44 +772,50 @@ Do you want to edit it with elevated privileges?</source>
 %1
 
 This action cannot be undone.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ali želite izbrisati conky datoteko:
+%1
+
+Tega dejanja ni mogoče razveljaviti.</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="561"/>
         <source>Conky file deleted successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky datoteak je bila uspešno izbrisana.</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="563"/>
         <source>Delete Failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Brisanje ni uspelo</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="563"/>
         <source>Failed to delete conky file:
 %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Conky datoteke
+%1
+ni bilo mogoče izbrisati</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="651"/>
         <source>Customize Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>Prilagodi Conky</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="652"/>
         <source>This conky file is read-only and requires administrator privileges to customize.
 Do you want to customize it with elevated privileges?</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta conky je zgolj za branje in za prilagajnje potrebuje skrbniške pravice.
+Ali ga želite prilagajati s povečanimi pravicami?</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="803"/>
         <source>Editor Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Napaka urejevalnika</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="803"/>
         <source>Cannot start editor for file: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Ne morem zagnati urejevalnnika za datoteko: %1</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="813"/>
@@ -853,12 +869,12 @@ Do you want to customize it with elevated privileges?</source>
     <message>
         <location filename="../src/previewdialog.cpp" line="50"/>
         <source>Generate Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustvari predogled</translation>
     </message>
     <message>
         <location filename="../src/previewdialog.cpp" line="75"/>
         <source>Generate preview images for</source>
-        <translation type="unfinished"></translation>
+        <translation>Ustvari predogledne slike za</translation>
     </message>
     <message>
         <location filename="../src/previewdialog.cpp" line="78"/>
@@ -954,17 +970,17 @@ Do you want to customize it with elevated privileges?</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/main.cpp" line="65"/>
+        <location filename="../src/main.cpp" line="68"/>
         <source>Select Conky Manager config file</source>
         <translation>Izberi konfiguracijsko datoteko za Conky upravljalnik</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="109"/>
+        <location filename="../src/main.cpp" line="112"/>
         <source>Error</source>
         <translation>Napaka</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="109"/>
+        <location filename="../src/main.cpp" line="112"/>
         <source>You must run this program as normal user</source>
         <translation>Ta program morate zagnati kot navaden uporabnik</translation>
     </message>
@@ -990,7 +1006,7 @@ Do you want to customize it with elevated privileges?</source>
     <message>
         <location filename="../src/settingsdialog.cpp" line="92"/>
         <source>Autostart</source>
-        <translation type="unfinished">Samodejni zagon</translation>
+        <translation>Samodejni zagon</translation>
     </message>
     <message>
         <location filename="../src/settingsdialog.cpp" line="167"/>
